==> haskell-http-common-0.8.2.0-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-common
version: 0.8.2.0
id: http-common-0.8.2.0-KW8jfERA8Q0FsZ6MisEclv
key: http-common-0.8.2.0-KW8jfERA8Q0FsZ6MisEclv
license: BSD-3-Clause
copyright: © 2012-2015 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: http://research.operationaldynamics.com/projects/http-streams/
synopsis: Common types for HTTP clients and servers
description:
    /Overview/
    .
    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.
category: Web
abi: 5a640ac17113dfce1cb6d7d5aeb514d6
exposed: True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-common-0.8.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-common-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-common-0.8.2.0
hs-libraries: HShttp-common-0.8.2.0-KW8jfERA8Q0FsZ6MisEclv
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-Isuu0DM5i6LOS2qIIf24
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk directory-1.3.3.0
    mtl-2.2.2 network-2.8.0.0-3PgnnHopFNTASnxFyU0kPh text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-DuDkJMfSb9t61flNcUovL1
haddock-interfaces: /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html: /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-common-0.8.2.0-57-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-common
version: 0.8.2.0
id: http-common-0.8.2.0-32ugCzeZSErAewkdOazL2h
key: http-common-0.8.2.0-32ugCzeZSErAewkdOazL2h
license: BSD-3-Clause
copyright: © 2012-2015 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: http://research.operationaldynamics.com/projects/http-streams/
synopsis: Common types for HTTP clients and servers
description:
    /Overview/
    .
    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.
category: Web
abi: 6b4695ceffa55e8e7b19252453d53085
exposed: True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-common-0.8.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-common-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-common-0.8.2.0
hs-libraries: HShttp-common-0.8.2.0-32ugCzeZSErAewkdOazL2h
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-C0hiEzqCknwIpHHXqmcpJo
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk directory-1.3.3.0
    mtl-2.2.2 network-2.8.0.0-HTKosw7lwpaCVnkz1nc19d text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
haddock-interfaces: /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html: /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
